pub trait IntoRow {
// Required methods
fn headers(&self) -> Row<'_>;
fn into_row(&self) -> Row<'_>;
}Expand description
A trait for types that know how to turn themselves into a table row.
Note that the tuple implementations of these methods always copy strings.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".